aboutsummaryrefslogtreecommitdiffstats
path: root/simulation/config
diff options
context:
space:
mode:
authorMission Liao <mission.liao@dexon.org>2018-09-20 09:09:37 +0800
committerGitHub <noreply@github.com>2018-09-20 09:09:37 +0800
commit421d72b2d796195178104a0eb1dedf319ba8664c (patch)
treef32f15c167989905494eca1891c3240b80dac1d6 /simulation/config
parent37f117d35c6617e1944d45e001e03813a6a278ed (diff)
downloaddexon-consensus-421d72b2d796195178104a0eb1dedf319ba8664c.tar
dexon-consensus-421d72b2d796195178104a0eb1dedf319ba8664c.tar.gz
dexon-consensus-421d72b2d796195178104a0eb1dedf319ba8664c.tar.bz2
dexon-consensus-421d72b2d796195178104a0eb1dedf319ba8664c.tar.lz
dexon-consensus-421d72b2d796195178104a0eb1dedf319ba8664c.tar.xz
dexon-consensus-421d72b2d796195178104a0eb1dedf319ba8664c.tar.zst
dexon-consensus-421d72b2d796195178104a0eb1dedf319ba8664c.zip
Rename validator* to node* (#120)
Diffstat (limited to 'simulation/config')
-rw-r--r--simulation/config/config.go8
1 files changed, 4 insertions, 4 deletions
diff --git a/simulation/config/config.go b/simulation/config/config.go
index ceb0abd..bddb19d 100644
--- a/simulation/config/config.go
+++ b/simulation/config/config.go
@@ -49,8 +49,8 @@ type Legacy struct {
ProposeIntervalSigma float64
}
-// Validator config for the simulation.
-type Validator struct {
+// Node config for the simulation.
+type Node struct {
Consensus Consensus
Legacy Legacy
Num int
@@ -75,7 +75,7 @@ type Scheduler struct {
// Config represents the configuration for simulation.
type Config struct {
Title string
- Validator Validator
+ Node Node
Networking Networking
Scheduler Scheduler
}
@@ -90,7 +90,7 @@ func GenerateDefault(path string) error {
config := Config{
Title: "DEXON Consensus Simulation Config",
- Validator: Validator{
+ Node: Node{
Consensus: Consensus{
PhiRatio: float32(2) / 3,
K: 1,